<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DateInputDialog</name>
    <message>
        <location filename="../dateinputdialog.ui" line="14"/>
        <source>Select Date</source>
        <translation>日時選択</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <location filename="../history.cpp" line="57"/>
        <source>History</source>
        <translation>履歴</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="58"/>
        <source>Alt+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryFactory</name>
    <message>
        <location filename="../historyfactory.cpp" line="31"/>
        <source>Listening History Plugin</source>
        <translation>視聴履歴プラグイン</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="51"/>
        <source>About Listening History Plugin</source>
        <translation>視聴履歴プラグインについて</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="52"/>
        <source>Qmmp Listening History Plugin</source>
        <translation>QMMP 視聴履歴プラグイン</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="53"/>
        <source>This plugin collects information about listened tracks</source>
        <translation>このプラグインは視聴したトラックの情報を収集します</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HistorySettingsDialog</name>
    <message>
        <location filename="../historysettingsdialog.ui" line="14"/>
        <source>Listening History Plugin Settings</source>
        <translation>視聴プラグインの設定</translation>
    </message>
    <message>
        <location filename="../historysettingsdialog.ui" line="31"/>
        <source>Title format:</source>
        <translation>表題の書式:</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <location filename="../historywindow.ui" line="14"/>
        <location filename="../historywindow.ui" line="110"/>
        <source>History</source>
        <translation>履歴</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="29"/>
        <source>Time Range</source>
        <translation>期間</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="35"/>
        <source>From:</source>
        <translation>自:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="52"/>
        <source>To:</source>
        <translation>至:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="69"/>
        <source>Last week</source>
        <translation>先週</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="76"/>
        <source>Last month</source>
        <translation>先月</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="83"/>
        <source>Execute</source>
        <translation>抽出</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="129"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="134"/>
        <location filename="../historywindow.ui" line="183"/>
        <source>Song</source>
        <translation>演目</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="143"/>
        <source>Distribution</source>
        <translation>普及</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="156"/>
        <source>Day</source>
        <translation>日付</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="161"/>
        <location filename="../historywindow.ui" line="188"/>
        <location filename="../historywindow.ui" line="215"/>
        <location filename="../historywindow.ui" line="242"/>
        <source>Play counts</source>
        <translation>配信回数</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="170"/>
        <source>Top Songs</source>
        <translation>上位の演目</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="197"/>
        <source>Top Artists</source>
        <translation>上位のアーティスト</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="210"/>
        <source>Artist</source>
        <translation>アーティスト</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="224"/>
        <source>Top Genres</source>
        <translation>上位のジャンル</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="237"/>
        <source>Genre</source>
        <translation>ジャンル</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="126"/>
        <source>dd MMMM yyyy</source>
        <translation>yyyy年MM月dd日</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="127"/>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="194"/>
        <source>MM-yyyy</source>
        <translation>yyyy年MM月</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="195"/>
        <source>dd MMMM</source>
        <translation>MM月dd日</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="495"/>
        <source>Add to Playlist</source>
        <translation>プレイリストに追加</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="496"/>
        <source>&amp;View Track Details</source>
        <translation>トラックの詳細を表示(&amp;D)</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="498"/>
        <source>Remove from History</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
